## needs comments & updated data saving. 
## check that 12345 works well with other images too. 
## then maybe update figures to be from this seed? 

set.seed(12345)

data <- read.csv("~/Dropbox/Local Linear Forests/Simulations/for-repo-eventually/welfarelabel.csv")

X.all = data[, c(1, 3:60)]

X.all$polviews[X.all$polviews == "4.1220088"] = NA
X.all$polviews = factor(X.all$polviews)
polviews = sapply(X.all$polviews, function(xx) {
  if(is.na(xx)) return(NA)
  if(xx == "extrmly conservative") return(3)
  if(xx == "conservative") return(2)
  if(xx == "slghtly conservative") return(1)
  if(xx == "extremely liberal") return(-3)
  if(xx == "liberal") return(-2)
  if(xx == "slightly liberal") return(-1)
  if(xx == "moderate") return(0)
})

X.all$income[X.all$income == "10.55557"] = NA
X.all$income = factor(X.all$income)
income = sapply(X.all$income, function(xx) {
  if(is.na(xx)) return(NA)
  if(xx == "$1000 to 2999") return(1)
  if(xx == "$10000 - 14999") return(10)
  if(xx == "$15000 - 19999") return(15)
  if(xx == "$20000 - 24999") return(20)
  if(xx == "$25000 or more") return(25)
  if(xx == "$3000 to 3999") return(3)
  if(xx == "$4000 to 4999") return(4)
  if(xx == "$5000 to 5999") return(5)
  if(xx == "$6000 to 6999") return(6)
  if(xx == "$7000 to 7999") return(7)
  if(xx == "$8000 to 9999") return(8)
  if(xx == "lt $1000") return(0)
})

year = as.numeric(X.all$year)

wrkstat = X.all$wrkstat
wrkstat[wrkstat == "2.900022"] = NA
wrkstat = factor(wrkstat)
wrkstat = as.numeric(wrkstat) # because grf can't currently do factors

X.all$childs = as.character(X.all$childs)
X.all$childs[X.all$childs == "1.8806012"] = NA
X.all$childs[X.all$childs == "eight or more"] = "8"
X.all$childs = as.numeric(X.all$childs)

X.all$age = as.character(X.all$age)
X.all$age[X.all$age == "46.091595"] = NA
X.all$age[X.all$age == "89 or older"] = 89
X.all$age = as.numeric(X.all$age)

X = data.frame(income, polviews, year, wrkstat, X.all$hrs1, X.all$hrs2, X.all$occ, X.all$prestige, X.all$prestg80, X.all$sibs, X.all$childs, X.all$age)

ok.idx = which(!is.na(rowSums(X) + data$y + data$w))
X = X[ok.idx,]
colnames(X) = 1:ncol(X)
Y = as.numeric(data$y)[ok.idx]
W = as.numeric(data$w)[ok.idx]

n = nrow(X)

############################### 
###### Boxplot Images #########
############################### 

views = seq(-3,3)
ntrain = 1000
ntest = 2000

# split data 
folds = c(rep(1,ntrain), rep(2, ntest), rep(3, nrow(X) - (ntrain+ntest)))
folds = sample(folds)

full = model.matrix(~., data = X)
X.train = full[folds == 1,]
Y.train = Y[folds == 1]
W.train = W[folds == 1]

X.test = full[folds == 2,]
Y.test = Y[folds ==2]
W.test = W[folds == 2]

# train forests 
forest = causal_forest(X.train, Y.train, W.train)
cate.forest = -predict(forest, X.test)$predictions

# select variables for LLF 
lasso.mod = cv.glmnet(X.train, Y.train, alpha=1)
lambda.min = lasso.mod$lambda.min
selected = as.numeric(predict(lasso.mod,s=lambda.min, type = "nonzero")[,1])

# LLF prediction 
cate = -predict(forest, X.test, linear.correction.variables = selected, ll.weight.penalty = TRUE)$predictions

# aggregate 
xj= X.test[,3]
df = data.frame(cbind(cate, cate.forest, xj))
colnames(df)=c("cate","forest","xj")

# find medians by category 
medians.cate = sapply(views, function(inc){
  median(df$cate[df$xj == inc])
})

medians.forest = sapply(views, function(inc){
  median(df$forest[df$xj == inc])
})

# generate boxplot for political views 
pdf("results/polviews.pdf")
pardef = par(xpd = FALSE, mar = c(4.5, 5, 3, 8) + 0.5, cex.lab=1.5, cex.axis=1.5, cex.main=1.5, cex.sub=1.5)
boxplot(cate ~ xj, data = df, at = views, xlim = c(-3.1,3.3), pars = list(boxwex=0.15),
        xlab = "<-- more liberal --- more conservative -->", ylab = "Estimated CATE")
boxplot(cate.forest ~ xj, data = df, at = views+0.25, add = TRUE, xaxt="n", pars = list(boxwex = 0.15)) 
points(views, medians.cate, 'l',lwd=2)
points(views+0.32, medians.forest,'l',lwd=2, lty = 2)
par(xpd = TRUE)
legend(3.7, 0.3, c("LLF", "CF"), lty = c(1, 2), lwd = c(2,2), cex = 1)
par = pardef
dev.off()

incomes = unique(income[!is.na(income)])
xj = X.test[,2]

df = data.frame(cbind(cate, cate.forest, xj))
colnames(df)=c("cate","forest","xj")

medians.cate = sapply(sort(incomes), function(inc){
  median(df$cate[df$xj == inc])
})

medians.forest = sapply(sort(incomes), function(inc){
  median(df$forest[df$xj == inc])
})

pdf("results/income.pdf")
pardef = par(xpd = FALSE, mar = c(4.5, 5, 3, 8) + 0.5, cex.lab=1.5, cex.axis=1.5, cex.main=1.5, cex.sub=1.5)
boxplot(cate ~ xj, data = df, at = sort(incomes), xlim = c(-0.1,25.3), pars = list(boxwex=0.3), 
        xlab = "Income Bracket", ylab = "Estimated CATE")
boxplot(cate.forest ~ xj, data = df, at = sort(incomes)+0.35, add = TRUE, xaxt="n", pars = list(boxwex = 0.3))
points(sort(incomes), medians.cate,'l',lwd=2)
points(sort(incomes)+0.35, medians.forest, 'l',lwd=2, lty = 2)
par(xpd = TRUE)
legend(27, max(df$cate,df$forest), c("LLF", "CF"), lty = c(1,2), lwd = c(2,2), cex = 1.5)
par = pardef
dev.off()


